% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/epi-functions.R, R/sirPlus-params.R
\name{set.param}
\alias{set.param}
\title{Set epidemic params}
\usage{
set.param(
  inf.prob.e = 0.02,
  act.rate.e = 10,
  inf.prob.i = 0.05,
  act.rate.i = 10,
  inf.prob.q = 0.02,
  act.rate.q = 2.5,
  quar.rate = 1/30,
  hosp.rate = 1/100,
  disch.rate = 1/15,
  prog.rate = 1/10,
  prog.dist.scale = 5,
  prog.dist.shape = 1.5,
  rec.rate = 1/20,
  rec.dist.scale = 35,
  rec.dist.shape = 1.5,
  fat.rate.base = 1/50,
  hosp.cap = 40,
  fat.rate.overcap = 1/25,
  fat.tcoeff = 0.5,
  vital = TRUE,
  a.rate = (10.5/365)/1000,
  a.prop.e = 0.01,
  a.prop.i = 0.001,
  a.prop.q = 0.01,
  ds.rate = (7/365)/1000,
  de.rate = (7/365)/1000,
  di.rate = (7/365)/1000,
  dq.rate = (7/365)/1000,
  dh.rate = (20/365)/1000,
  dr.rate = (7/365)/1000,
  out = "mean"
)

set.param(
  inf.prob.e = 0.02,
  act.rate.e = 10,
  inf.prob.i = 0.05,
  act.rate.i = 10,
  inf.prob.q = 0.02,
  act.rate.q = 2.5,
  quar.rate = 1/30,
  hosp.rate = 1/100,
  disch.rate = 1/15,
  prog.rate = 1/10,
  prog.dist.scale = 5,
  prog.dist.shape = 1.5,
  rec.rate = 1/20,
  rec.dist.scale = 35,
  rec.dist.shape = 1.5,
  fat.rate.base = 1/50,
  hosp.cap = 40,
  fat.rate.overcap = 1/25,
  fat.tcoeff = 0.5,
  vital = TRUE,
  a.rate = (10.5/365)/1000,
  a.prop.e = 0.01,
  a.prop.i = 0.001,
  a.prop.q = 0.01,
  ds.rate = (7/365)/1000,
  de.rate = (7/365)/1000,
  di.rate = (7/365)/1000,
  dq.rate = (7/365)/1000,
  dh.rate = (20/365)/1000,
  dr.rate = (7/365)/1000,
  out = "mean"
)
}
\arguments{
\item{inf.prob.e}{Probability of passing on infection at each 
exposure event for interactions between infectious people in the E 
compartment and susceptibles in S. Note the default is lower than for 
inf.prob.i reflecting the reduced infectivity of infected but 
asymptomatic people (the E compartment). Otherwise as for inf.exp.i.}

\item{act.rate.e}{The number of exposure events (acts) between 
infectious individuals in the E compartment and susceptible individuals 
in the S compartment, per day. Otherwise as for act.rate.i.}

\item{inf.prob.i}{Probability of passing on infection at each 
exposure event for interactions between infectious people in the I
compartment and susceptibles in S. Reducing inf.prob.i is equivalent to 
increasing hygiene measures, such as not putting hands in eyes, nose or 
moth, use of hand sanitisers, wearing masks by the infected, and so on.}

\item{act.rate.i}{The number of exposure events (acts) between 
infectious individuals in the I compartment and susceptible individuals 
in the S compartment, per day. It's stochastic, so the rate is an
average, some individuals may have more or less. Note that not every 
exposure event results in infection - that is governed by the inf.prob.i
parameters (see below). Reducing act.rate.i is equivalent to increasing 
social distancing by people in the I compartment.}

\item{inf.prob.q}{Probability of passing on infection at each 
exposure event for interactions between infectious people in the Q 
compartment and susceptibles in S. Note the default is lower than for 
inf.prob.i reflecting the greater care that self-isolated individuals 
will, on average, take regarding hygiene measures, such as wearing masks,
to limit spread to others. Otherwise as for inf.exp.i.}

\item{act.rate.q}{The number of exposure events (acts) between 
infectious individuals in the Q compartment (isolated, self or otherwise)
and susceptible individuals in the S compartment, per day. Note the much
lower rate than for the I and E compartments, reflecting the much 
greater degree of social isolation for someone in (self-)isolation. The
exposure event rate is not zero for this group, just much less. 
Otherwise as for act.rate.i.}

\item{quar.rate}{Rate per day at which symptomatic (or tested 
positive), infected I compartment people enter self-isolation (Q 
compartment). Asymptomatic E compartment people can't enter 
self-isolation because they don't yet know they are infected. Default is
a low rate reflecting low community awareness or compliance with 
self-isolation requirements or practices, but this can be tweaked when
exploring scenarios.}

\item{hosp.rate}{Rate per day at which symptomatic (or tested 
positive), infected I compartment people or self-isolated Q compartment
people enter the state of requiring hospital care -- that is, become 
serious cases. A default rate of 1% per day with an average illness 
duration of about 10 days means a bit less than 10% of cases will 
require hospitalisation, which seems about right (but can be tweaked, 
of course).}

\item{disch.rate}{Rate per day at which people needing 
hospitalisation recover.}

\item{prog.rate}{Rate per day at which people who are infected 
but asymptomatic (E compartment) progress to becoming symptomatic (or 
test-positive), the I compartment. See prog.rand above for more details.}

\item{prog.dist.scale}{Scale parameter for Weibull distribution 
for progression, see prog.rand for details.}

\item{prog.dist.shape}{Shape parameter for Weibull distribution 
for progression, see prog.rand for details. Read up on the Weibull 
distribution before changing the default.}

\item{rec.rate}{Rate per day at which people who are infected and
symptomatic (I compartment) recover, thus entering the R compartment. 
See rec.rand above for more details.}

\item{rec.dist.scale}{Scale parameter for Weibull distribution for
recovery, see rec.rand for details.}

\item{rec.dist.shape}{Shape parameter for Weibull distribution for
recovery, see rec.rand for details. Read up on the Weibull distribution
before changing the default.}

\item{fat.rate.base}{Baseline mortality rate per day for people 
needing hospitalisation (deaths due to the virus). See fat.rand for more
details.}

\item{hosp.cap}{Number of available hospital beds for the modelled
population. See fat.rand for more details.}

\item{fat.rate.overcap}{Mortality rate per day for people needing
hospitalisation but who can't get into hospital due to the hospitals 
being full (see hosp.cap and fat.rand). The default rate is twice that 
for those who do get into hospital.}

\item{fat.tcoeff}{Time co-efficient for increasing mortality rate 
as time in the H compartment increases for each individual in it. See 
fat.rand for details.}

\item{vital}{Enables demographics, that is, arrivals and 
departures, to and from the simulated population.}

\item{a.rate}{Background demographic arrival rate. Currently all 
arrivals go into the S compartment, the default is approximately the 
daily birth rate for Australia. Will be extended to cover immigration in
future versions.}

\item{ds.rate}{Background demographic departure (death not due to
virus) rates. Defaults based on Australian crude death rates. Can be 
used to model emigration as well as deaths.}

\item{de.rate}{Background demographic departure (death not due to 
virus) rates. Defaults based on Australian crude death rates. Can be used
to model emigration as well as deaths.}

\item{dq.rate}{Background demographic departure (death not due to 
virus) rates. Defaults based on Australian crude death rates. Can be used
to model emigration as well as deaths.}

\item{dh.rate}{Background demographic departure (death not due to 
virus) rates. Defaults based on Australian crude death rates. Can be used
to model emigration as well as deaths.}

\item{dr.rate}{Background demographic departure (death not due to 
virus) rates. Defaults based on Australian crude death rates. Can be used 
to model emigration as well as deaths.}

\item{out}{Summary function for the simulation runs. median is 
also available, or percentiles, see the EpiModel documentation.}
}
\value{
param.icm object

param.icm object
}
\description{
Sets the epidemic parameters for stochastic individual contact models 
simulated with icm.

Sets the epidemic parameters for stochastic individual contact models 
simulated with icm.
}
